@@ -24,7 +24,7 @@
 int gengetopt_define_package (char * s) ;
 int gengetopt_define_version (char * s) ;
 int gengetopt_define_purpose (char * s) ;
-void gengetopt_set_section (const char * s) ;
+void gengetopt_set_section (const char * s, const char *sd) ;
 int gengetopt_add_group (const char * s, const char *desc, int required) ;
 int gengetopt_add_option (const char * long_opt, char short_opt, 
                           const char * desc, 
