@@ -17,9 +17,9 @@ main (int argc, char **argv)
   if (test_conf_parser_cmd_parser (argc, argv, &args_info) != 0)
     exit(1) ;
 
-  /* override cmd options, but do not initialize args_info */
+  /* override cmd options, but do not initialize args_info, check for required options */
   if (test_conf_parser_cmd_parser_configfile
-      (args_info.conf_file_arg, &args_info, 1, 0) != 0) 
+      (args_info.conf_file_arg, &args_info, 1, 0, 1) != 0) 
     exit(1);
 
   printf ("value of required: %s\n", args_info.required_arg);
