@@ -38,6 +38,16 @@ main (int argc, char **argv)
   printf ("noarg given %d times\n", args_info.noarg_given);
   printf ("noarg_noshort given %d times\n", args_info.noarg_noshort_given);
 
+  printf ("optarg_given %d times\n", args_info.optarg_given);
+  for (i = 0; i < args_info.optarg_given; ++i)
+    printf ("optarg argument: %s\n", 
+            (args_info.optarg_arg[i] ? args_info.optarg_arg[i] : "no arg given"));
+
+  printf ("optarg_noshort_given %d times\n", args_info.optarg_noshort_given);
+  for (i = 0; i < args_info.optarg_noshort_given; ++i)
+    printf ("optarg_noshort argument: %s\n", 
+            (args_info.optarg_noshort_arg[i] ? args_info.optarg_noshort_arg[i] : "no arg given"));
+
   test_multiple_cmd_parser_free (&args_info);
 
   return 0;
